==> slipstream-0.1.tar.gz: slipstream-0.1/src/pages/wait.lua <==
<!--
    Copyright (C) 2008 Papavasileiou Dimitris                             
                                                                     
    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or    
    (at your option) any later version.                                  
    
    This program is distributed in the hope that it will be useful,      
    but WITHOUT ANY WARRANTY; without even the implied warranty of       
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
    GNU General Public License for more details.                         
                                                                     
    You should have received a copy of the GNU General Public License    
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->

<head>
  <title>In session</title>
  <link rel="stylesheet" href="/stylesheet" type="text/css">
</head>

<body onload="javascript:window.blur();">
  <table class="splashscreen">
     <tr><td>
	 <div>
	   <h1> Race in progress... </h1>
	 </div>
     </td></tr>
  </table>

  <script type="text/javascript">
    var request

    request = new XMLHttpRequest();

    function check()
    {
       if (request.readyState == 4) {
	  window.location = "/slipstream";
       }
    }

    request.open("HEAD", "/slipstream", true);
    request.onreadystatechange = check;
    request.send(null);
  </script>
</body>

==> slipstream-0.2.tar.gz: slipstream-0.2/src/pages/wait.lua <==
<!--
    Copyright (C) 2008 Papavasileiou Dimitris                             
                                                                     
    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or    
    (at your option) any later version.                                  
    
    This program is distributed in the hope that it will be useful,      
    but WITHOUT ANY WARRANTY; without even the implied warranty of       
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
    GNU General Public License for more details.                         
                                                                     
    You should have received a copy of the GNU General Public License    
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->

<head>
  <title>In session</title>
  <link rel="stylesheet" href="/stylesheet" type="text/css">
</head>

<body onload="javascript:window.blur();">
  <table class="splashscreen">
     <tr><td>
	 <div>
	   <h1> Race in progress... </h1>
	 </div>
     </td></tr>
  </table>

  <script type="text/javascript">
    var request

    request = new XMLHttpRequest();

    function check()
    {
       if (request.readyState == 4) {
	  window.location = "/slipstream/sessions/current";
       }
    }

    request.open("HEAD", "/slipstream/sessions/inprogress", true);
    request.onreadystatechange = check;
    request.send(null);
  </script>
</body>
